@@ -1,9 +1,12 @@
 """Tagger module for high level API."""
+from __future__ import annotations
+
 from dataclasses import dataclass, field
 
 import h5py
 import numpy as np
 import pandas as pd
+from ftag import Flavour, Flavours
 from numpy.lib.recfunctions import structured_to_unstructured
 
 from puma.utils import calc_disc, logger
@@ -18,10 +21,11 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
     reference: bool = False
 
     scores = None
+    labels = None
     perf_var = None
-    output_nodes: list = field(default_factory=lambda: ["ujets", "cjets", "bjets"])
-
-    is_flav: dict = field(default_factory=dict)
+    output_nodes: list = field(
+        default_factory=lambda: [Flavours.ujets, Flavours.cjets, Flavours.bjets]
+    )
 
     colour: str = None
 
@@ -37,8 +41,35 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
     def __repr__(self):
         return f"{self.name} ({self.label})"
 
+    def is_flav(self, flavour: Flavour | str):
+        """Return indices of jets of given flavour.
+
+        Parameters
+        ----------
+        flavour : str
+            Flavour to select
+
+        Returns
+        -------
+        np.ndarray
+            Array of indices of the given flavour
+        """
+        flavour = Flavours[flavour] if isinstance(flavour, str) else flavour
+        return flavour.cuts(self.labels).idx
+
     @property
-    def probailities(self):
+    def output_nodes_lower(self):
+        """Return the lowercase output nodes.
+
+        Returns
+        -------
+        list
+            List of lower case output nodes
+        """
+        return [x.name.lower() for x in self.output_nodes]
+
+    @property
+    def probabilities(self):
         """Return the probabilities of the tagger.
 
         Returns
@@ -46,7 +77,7 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
         list
             List of probability names
         """
-        return [f"p{flv.rstrip('jets')}" for flv in self.output_nodes]
+        return [flav.px for flav in self.output_nodes]
 
     @property
     def variables(self):
@@ -58,7 +89,7 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
             List of the outputs variable names of the tagger
         """
 
-        return [f"{self.name}_{prob}" for prob in self.probailities]
+        return [f"{self.name}_{prob}" for prob in self.probabilities]
 
     def extract_tagger_scores(
         self, source: object, source_type: str = "data_frame", key: str = None
@@ -85,7 +116,6 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
         ValueError
             if source_type is wrongly specified
         """
-        # TODO: change to case syntax in python 3.10
         if source_type == "data_frame":
             logger.debug("Retrieving tagger `%s` from data frame.", self.name)
             self.scores = source[self.variables].values
@@ -127,12 +157,12 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
         else:
             raise ValueError(f"{source_type} is not a valid value for `source_type`.")
 
-    def n_jets(self, flavour: str):
+    def n_jets(self, flavour: Flavour | str):
         """Retrieve number of jets of a given flavour.
 
         Parameters
         ----------
-        flavour : str
+        flavour : Flavour | str
             Flavour of jets to count
 
         Returns
@@ -140,9 +170,10 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
         int
             Number of jets of given flavour
         """
-        return int(np.sum(self.is_flav[flavour]))
+        flavour = Flavours[flavour] if isinstance(flavour, str) else flavour
+        return len(flavour.cuts(self.labels).values)
 
-    def get_disc(self, signal_class: str):
+    def get_disc(self, signal_class: Flavour):
         """Retrieve the discriminant for a given signal class.
 
         Parameters
@@ -160,12 +191,12 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
         ValueError
             If no discriminant is defined for given signal class
         """
-        if signal_class == "bjets":
+        if signal_class == Flavours.bjets:
             return self.calc_disc_b()
-        if signal_class == "cjets":
+        if signal_class == Flavours.cjets:
             return self.calc_disc_c()
-        if signal_class in ("Hbb", "Hcc"):
-            return self.scores[:, self.output_nodes.index(signal_class)]
+        if signal_class in (Flavours.hbb, Flavours.hcc):
+            return self.scores[:, self.output_nodes_lower.index(signal_class.name)]
         raise ValueError(f"No discriminant defined for {signal_class} signal.")
 
     def calc_disc_b(self) -> np.ndarray:
@@ -191,7 +222,7 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
         }
         return calc_disc(
             scores=self.scores,
-            flvs=self.probailities,
+            flvs=self.probabilities,
             flv_map=flv_map,
         )
 
@@ -218,6 +249,6 @@ class Tagger:  # pylint: disable=too-many-instance-attributes
         }
         return calc_disc(
             scores=self.scores,
-            flvs=self.probailities,
+            flvs=self.probabilities,
             flv_map=flv_map,
         )
